@@ -1,3 +1,6 @@
+import os
+
+
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
@@ -6,6 +9,10 @@ DATABASES = {
 }
 SECRET_KEY = "un33k"
 
+TEMPLATE_DIRS = [
+    '%s' % os.path.abspath(os.path.join(os.path.dirname(__file__), 'templates')),
+]
+
 # Static file finders in order of precedence
 #######################################
 STATICFILES_FINDERS = [
@@ -56,11 +63,11 @@ SITE_OBJECTS_INFO_DICT = {
         'name': 'production',
         'domain': 'example.com',
     },
-    '2':{
+    '2': {
         'name': 'integration',
         'domain': 'example.org'
     },
-    '3':{
+    '3': {
         'name': 'development',
         'domain': '192.168.1.20:8080'
     },
@@ -76,3 +83,5 @@ SITE_SUPERUSER_ID = '22'
 SITE_SUPERUSER_USERNAME = 'admin'
 SITE_SUPERUSER_EMAIL = 'admin@example.com'
 SITE_SUPERUSER_PASSWORD = 'coolpass'
+
+TEST_RUNNER = 'django.test.runner.DiscoverRunner'
