@@ -2,6 +2,8 @@ from django.test import TestCase
 from django.conf import settings
 from django.contrib.sites.models import Site
 from django.contrib.auth import get_user_model
+from django.test.utils import setup_test_environment
+
 
 from finalware import defaults
 
@@ -10,8 +12,11 @@ class SiteTestCase(TestCase):
     """
     Site objects are created
     """
+
     def setUp(self):
-        self.resp = self.client.get('/admin')
+        setup_test_environment()
+        self.resp = self.client.get('/make_request/')
+        self.assertEqual(self.resp.status_code, 200)
 
     def test_current_site_object(self):
         curr = Site.objects.get_current()
@@ -21,16 +26,15 @@ class SiteTestCase(TestCase):
         sites = Site.objects.count()
         self.assertEquals(sites, len(defaults.SITE_OBJECTS_INFO_DICT))
 
-    def test_admin_page(self):
-        self.assertEqual(self.resp.status_code, 200)
-
 
 class ContextTestCase(TestCase):
     """
     Context is filled in
     """
     def setUp(self):
-        self.resp = self.client.get('/admin')
+        setup_test_environment()
+        self.resp = self.client.get('/make_request/')
+        self.assertEqual(self.resp.status_code, 200)
 
     def test_context_site(self):
         curr_site = Site.objects.get_current()
@@ -60,6 +64,7 @@ class SuperuserTestCase(TestCase):
     Site objects are created
     """
     def setUp(self):
+        setup_test_environment()
         User = get_user_model()
         self.user = User.objects.get(pk=settings.SITE_SUPERUSER_ID)
 
