@@ -9,7 +9,6 @@ from . import defaults
 log = logging.getLogger(__name__)
 
 
-
 # Setup the available sites for this project
 def load_site_objects():
     """
@@ -25,6 +24,7 @@ def load_site_objects():
                 site.domain = site_info[pk]['domain']
                 site.save()
 
+
 def load_template_tags():
     """
     Loads template tags found in SITE_TEMPLATE_TAGS_AUTO_LOAD_LIST on startup
@@ -32,6 +32,7 @@ def load_template_tags():
     for t in defaults.SITE_TEMPLATE_TAGS_AUTO_LOAD_LIST:
         template.add_to_builtins(t)
 
+
 def create_superuser():
     """
     Create or update a superuser.
@@ -54,3 +55,13 @@ def create_superuser():
             user.is_superuser = True
             user.save()
             log.info(_('Superuser created/updated'))
+
+
+def is_last_installed_app(app_config):
+    """
+    Returns True if this app is the last installed application
+    Returns False if this app is not installed or not the last application
+    """
+    if app_config.label == settings.INSTALLED_APPS[-1].split('.')[-1]:
+        return True
+    return False
